CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
100 lines
3.9 KiB
C
100 lines
3.9 KiB
C
/* ************************************************************************
|
|
* Copyright (C) 2025 Advanced Micro Devices, Inc. All rights Reserved.
|
|
*
|
|
* Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
* of this software and associated documentation files (the "Software"), to deal
|
|
* in the Software without restriction, including without limitation the rights
|
|
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
* copies of the Software, and to permit persons to whom the Software is
|
|
* furnished to do so, subject to the following conditions:
|
|
*
|
|
* The above copyright notice and this permission notice shall be included in
|
|
* all copies or substantial portions of the Software.
|
|
*
|
|
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
* THE SOFTWARE.
|
|
*
|
|
* ************************************************************************ */
|
|
|
|
#include <hip/hip_runtime_api.h>
|
|
#include <hipsparse/hipsparse.h>
|
|
#include <stdio.h>
|
|
#include <stdlib.h>
|
|
|
|
#define HIP_CHECK(stat) \
|
|
{ \
|
|
if(stat != hipSuccess) \
|
|
{ \
|
|
fprintf(stderr, "Error: hip error in line %d\n", __LINE__); \
|
|
return -1; \
|
|
} \
|
|
}
|
|
|
|
#define HIPSPARSE_CHECK(stat) \
|
|
{ \
|
|
if(stat != HIPSPARSE_STATUS_SUCCESS) \
|
|
{ \
|
|
fprintf(stderr, "Error: hipsparse error in line %d\n", __LINE__); \
|
|
return -1; \
|
|
} \
|
|
}
|
|
|
|
int main()
|
|
{
|
|
// Number of non-zeros of the sparse vector
|
|
int nnz = 3;
|
|
|
|
// Sparse index vector
|
|
int hxInd[3] = {0, 3, 5};
|
|
|
|
// Sparse value vector
|
|
double hxVal[3] = {1.0, 2.0, 3.0};
|
|
|
|
// Dense vector
|
|
double hy[9] = {1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0};
|
|
|
|
// Scalar alpha
|
|
double alpha = 3.7;
|
|
|
|
// Index base
|
|
hipsparseIndexBase_t idxBase = HIPSPARSE_INDEX_BASE_ZERO;
|
|
|
|
// Offload data to device
|
|
int* dxInd;
|
|
double* dxVal;
|
|
double* dy;
|
|
|
|
HIP_CHECK(hipMalloc((void**)&dxInd, sizeof(int) * nnz));
|
|
HIP_CHECK(hipMalloc((void**)&dxVal, sizeof(double) * nnz));
|
|
HIP_CHECK(hipMalloc((void**)&dy, sizeof(double) * 9));
|
|
|
|
HIP_CHECK(hipMemcpy(dxInd, hxInd, sizeof(int) * nnz, hipMemcpyHostToDevice));
|
|
HIP_CHECK(hipMemcpy(dxVal, hxVal, sizeof(double) * nnz, hipMemcpyHostToDevice));
|
|
HIP_CHECK(hipMemcpy(dy, hy, sizeof(double) * 9, hipMemcpyHostToDevice));
|
|
|
|
// hipSPARSE handle
|
|
hipsparseHandle_t handle;
|
|
HIPSPARSE_CHECK(hipsparseCreate(&handle));
|
|
|
|
// Call daxpyi to perform y = y + alpha * x
|
|
HIPSPARSE_CHECK(hipsparseDaxpyi(handle, nnz, &alpha, dxVal, dxInd, dy, idxBase));
|
|
|
|
// Copy result back to host
|
|
HIP_CHECK(hipMemcpy(hy, dy, sizeof(double) * 9, hipMemcpyDeviceToHost));
|
|
|
|
// Clear hipSPARSE
|
|
HIPSPARSE_CHECK(hipsparseDestroy(handle));
|
|
|
|
// Clear device memory
|
|
HIP_CHECK(hipFree(dxInd));
|
|
HIP_CHECK(hipFree(dxVal));
|
|
HIP_CHECK(hipFree(dy));
|
|
|
|
return 0;
|
|
}
|